Documentation
¶
Index ¶
Constants ¶
const ( KeyEngine = "engine" KeyUID = "uid" KeyNamespace = "namespace" KeyPodSelector = "podSelector" KeyTopoConfigPath = "topologyConfigPath" KeyTopoConfigmapName = "topologyConfigmapName" KeyBlockSizes = "block_sizes" KeyPlugin = "plugin" TopologyTree = "topology/tree" TopologyBlock = "topology/block" TopologyFlat = "topology/flat" NoTopology = "no-topology" KeyNodeInstance = "topograph.nvidia.com/instance" KeyNodeRegion = "topograph.nvidia.com/region" KeyNodeClusterID = "topograph.nvidia.com/cluster-id" // ConfigMap annotation keys for metadata tracking KeyConfigMapEngine = "topograph.nvidia.com/engine" KeyConfigMapTopologyManagedBy = "topograph.nvidia.com/topology-managed-by" KeyConfigMapLastUpdated = "topograph.nvidia.com/last-updated" KeyConfigMapPlugin = "topograph.nvidia.com/plugin" KeyConfigMapBlockSizes = "topograph.nvidia.com/block-sizes" KeyConfigMapNamespace = "topograph.nvidia.com/slurm-namespace" )
Variables ¶
This section is empty.
Functions ¶
func GetNodeNameList ¶
func GetNodeNameList(cis []ComputeInstances) []string
GetNodeNameList retrieves all the nodenames
func GetNodeNameMap ¶
func GetNodeNameMap(cis []ComputeInstances) map[string]bool
GetNodeNameMap retrieves all the nodenames
Types ¶
type ClusterTopology ¶
type ClusterTopology struct {
Instances []*InstanceTopology
}
func NewClusterTopology ¶
func NewClusterTopology() *ClusterTopology
func (*ClusterTopology) Append ¶
func (c *ClusterTopology) Append(inst *InstanceTopology)
func (*ClusterTopology) Len ¶
func (c *ClusterTopology) Len() int
func (*ClusterTopology) Normalize ¶
func (c *ClusterTopology) Normalize()
func (*ClusterTopology) ToThreeTierGraph ¶
func (c *ClusterTopology) ToThreeTierGraph(provider string, cis []ComputeInstances, normalize bool) (*Vertex, error)
type ComputeInstances ¶
type DomainMap ¶
DomainMap maps domain name to a map of hostname:instance
func NewDomainMap ¶
func NewDomainMap() DomainMap
type InstanceTopology ¶
type InstanceTopology struct {
InstanceID string
BlockID string
BlockName string // optional
SpineID string
SpineName string // optional
DatacenterID string
DatacenterName string // optional
AcceleratorID string
}
func (*InstanceTopology) String ¶
func (inst *InstanceTopology) String() string
type Merger ¶
type Merger struct {
// contains filtered or unexported fields
}
Merger finds and merges similar vertices in a graph representing N-tier hierarchy
type Request ¶
type Request struct {
Provider Provider `json:"provider"`
Engine Engine `json:"engine"`
Nodes []ComputeInstances `json:"nodes"`
}
func GetTopologyRequest ¶
func NewRequest ¶
Click to show internal directories.
Click to hide internal directories.